@@ -24,6 +24,7 @@ import org.mortbay.io.Buffers;
 import org.mortbay.io.ByteArrayBuffer;
 import org.mortbay.io.Connection;
 import org.mortbay.io.EndPoint;
+import org.mortbay.io.View;
 import org.mortbay.io.nio.SelectChannelEndPoint;
 import org.mortbay.jetty.HttpGenerator;
 import org.mortbay.jetty.HttpHeaderValues;
@@ -51,7 +52,6 @@ public class HttpConnection implements Connection
     Buffer _connectionHeader;
     Buffer _requestContentChunk;
     boolean _requestComplete;
-    public String _message;
     public boolean _reserved;
     // The current exchange waiting for a response
     volatile HttpExchange _exchange;
@@ -140,7 +140,6 @@ public class HttpConnection implements Connection
     public void handle() throws IOException
     {
         int no_progress = 0;
-        long flushed = 0;
 
         boolean failed = false;
         while (_endp.isBufferingInput() || _endp.isOpen())
@@ -200,7 +199,7 @@ public class HttpConnection implements Connection
                     {
                         if (_exchange == null)
                             continue;
-                        flushed = _generator.flush();
+                        long flushed = _generator.flush();
                         io += flushed;
                     }
 
@@ -396,7 +395,7 @@ public class HttpConnection implements Connection
             {
                 _exchange._requestFields.putLongField(HttpHeaders.CONTENT_LENGTH,_exchange._requestContent.length());
                 _generator.completeHeader(_exchange._requestFields,false);
-                _generator.addContent(_exchange._requestContent,true);
+                _generator.addContent(new View(_exchange._requestContent),true);
             }
             else if (_exchange._requestContentSource != null)
             {
@@ -524,12 +523,25 @@ public class HttpConnection implements Connection
     /* ------------------------------------------------------------ */
     public void close() throws IOException
     {
-        _endp.close();
+        try
+        {
+            _endp.close();
+        }
+        finally
+        {
+            HttpExchange exchange=_exchange;
+            if (exchange!=null)
+            {
+                int status = exchange.getStatus();
+                if (status>HttpExchange.STATUS_START && status<HttpExchange.STATUS_COMPLETED)
+                    exchange.onException(new IOException("CLOSED"));
+            }
+        }
     }
 
 
     /* ------------------------------------------------------------ */
-    public void setIdleTimeout(long expire)
+    public void setIdleTimeout()
     {
         synchronized (this)
         {
@@ -539,7 +551,7 @@ public class HttpConnection implements Connection
                 throw new IllegalStateException();
         }
     }
-    
+
     /* ------------------------------------------------------------ */
     public boolean cancelIdleTimeout()
     {
@@ -551,7 +563,7 @@ public class HttpConnection implements Connection
                 return true;
             }
         }
-        
+
         return false;
     }
 
