@@ -437,6 +437,8 @@ public class HttpExchange
     public void setRequestContentSource(InputStream in)
     {
         _requestContentSource = in;
+        if (_requestContentSource.markSupported())
+            _requestContentSource.mark(Integer.MAX_VALUE);
     }
 
     /* ------------------------------------------------------------ */
@@ -476,11 +478,13 @@ public class HttpExchange
         return _requestContent;
     }
 
+    /* ------------------------------------------------------------ */
     public boolean getRetryStatus()
     {
         return _retryStatus;
     }
 
+    /* ------------------------------------------------------------ */
     public void setRetryStatus( boolean retryStatus )
     {
         _retryStatus = retryStatus;
@@ -604,6 +608,18 @@ public class HttpExchange
      */
     protected void onRetry() throws IOException
     {
+        if (_requestContentSource != null)
+        {
+            if (_requestContentSource.markSupported())
+            {
+                _requestContent = null;
+                _requestContentSource.reset();
+            }
+            else
+            {
+                throw new IOException("Unsupported retry attempt");
+            }
+        }
     }
 
     /**
@@ -741,7 +757,7 @@ public class HttpExchange
             }
             catch (IOException e)
             {
-                Log.debug(e);
+                onException(e);
             }
         }
     }
