@@ -53,7 +53,7 @@ public abstract class AbstractGenerator implements Generator
     public final static int STATE_FLUSHING = 3;
     public final static int STATE_END = 4;
     
-    private static byte[] NO_BYTES = {};
+    private static final byte[] NO_BYTES = {};
     private static int MAX_OUTPUT_CHARS = 512; 
 
     private static Buffer[] __reasons = new Buffer[505];
@@ -577,6 +577,7 @@ public abstract class AbstractGenerator implements Generator
         {
             _buf.wrap(b, off, len);
             write(_buf);
+            _buf.wrap(NO_BYTES);
         }
 
         /* ------------------------------------------------------------ */
@@ -587,6 +588,7 @@ public abstract class AbstractGenerator implements Generator
         {
             _buf.wrap(b);
             write(_buf);
+            _buf.wrap(NO_BYTES);
         }
 
         /* ------------------------------------------------------------ */
