@@ -778,6 +778,7 @@ public class HttpConnection implements Connection
             }
             catch (Exception e)
             {
+                Log.debug(e);
                 throw new HttpException(HttpStatus.ORDINAL_400_Bad_Request,null,e);
             }
         }
@@ -863,6 +864,8 @@ public class HttpConnection implements Connection
          */
         public void headerComplete() throws IOException
         {
+            if (_endp instanceof SelectChannelEndPoint)
+                ((SelectChannelEndPoint)_endp).scheduleIdle();
             _requests++;
             _generator.setVersion(_version);
             switch (_version)
@@ -932,6 +935,8 @@ public class HttpConnection implements Connection
          */
         public void content(Buffer ref) throws IOException
         {
+            if (_endp instanceof SelectChannelEndPoint)
+                ((SelectChannelEndPoint)_endp).scheduleIdle();
             if (_delayedHandling)
             {
                 _delayedHandling = false;
